@@ -77,11 +77,12 @@ qSIP_atom_excess_format = function(physeq, control_expr, treatment_rep){
                           include_sample_data=TRUE,
                           sample_col_keep=cols,
                           control_expr=control_expr)
+
   # removing 'infinite' BD values
   tmp = colnames(df_OTU)
   df_OTU = df_OTU %>%
-    dplyr::mutate_(Buoyant_density = "HTSSIP::as.Num(Buoyant_density)",
-                   Count = "HTSSIP::as.Num(Count)") %>%
+    dplyr::mutate_(Buoyant_density = "as.numeric(as.character(Buoyant_density))",
+                   Count = "as.numeric(as.character(Count))") %>%
     dplyr::filter_('! is.infinite(Buoyant_density)') %>%
     dplyr::filter_('! is.na(Buoyant_density)') %>%
     as.data.frame
@@ -116,8 +117,8 @@ qSIP_atom_excess_format = function(physeq, control_expr, treatment_rep){
 #' \dontrun{
 #' # BD shift (Z) & atom excess (A)
 #' atomX = qSIP_atom_excess(physeq_rep3_t,
-#'                         control_expr='Treatment=="12C-Con"',
-#'                         treatment_rep='Replicate')
+#'                          control_expr='Treatment=="12C-Control"',
+#'                          treatment_rep='Replicate')
 #' }
 #'
 qSIP_atom_excess = function(physeq,
@@ -141,14 +142,13 @@ qSIP_atom_excess = function(physeq,
     # BD shift (Z)
     df_OTU_W = df_OTU %>%
       # weighted mean buoyant density (W)
-      dplyr::mutate_(Buoyant_density = "HTSSIP::as.Num(Buoyant_density)",
-                     Count = "HTSSIP::as.Num(Count)") %>%
+      dplyr::mutate_(Buoyant_density = "as.numeric(as.character(Buoyant_density))",
+                     Count = "as.numeric(as.character(Count))") %>%
       dplyr::group_by_('IS_CONTROL', 'OTU', treatment_rep) %>%
       dplyr::summarize_(W = "stats::weighted.mean(Buoyant_density, Count, na.rm=TRUE)") %>%
       dplyr::ungroup()
   }
 
-
   df_OTU_s = df_OTU_W %>%
     # mean W of replicate gradients
     dplyr::group_by_('IS_CONTROL', 'OTU') %>%
